#
# spec file for package libksysguard6
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.5.0
%define qt6_version 6.7.0

%define rname libksysguard

%bcond_without released

# Full Plasma 5 version (e.g. 5.8.95)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 5.8 in KF6, but 5.8.95 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
Name:           libksysguard6
Version:        6.2.1
Release:        1.1
Summary:        Task management and system monitoring library
License:        GPL-2.0-or-later
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
Source3:        libksysguard6-rpmlintrc
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  libsensors4-devel
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6Auth) >= %{kf6_version}
BuildRequires:  cmake(KF6Completion) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6JobWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6NewStuff) >= %{kf6_version}
BuildRequires:  cmake(KF6Package) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6UiPlugin) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(libpcap)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xres)
BuildRequires:  pkgconfig(zlib)
# Has no effect, we use set_permissions
# BuildRequires:  libcap-progs
Recommends:     libksysguard6-imports
Recommends:     libksysguard6-plugins
Provides:       libksysguard5 = %{version}
Obsoletes:      libksysguard5 < %{version}
Obsoletes:      libksysguard5-lang < %{version}

%description
Task management and system monitoring library.

%package -n libKSysGuardSystemStats2
Summary:        Library for system monitoring plugins for KSystemStats
Requires:       ksysguardsystemstats6-data >= %{version}

%description -n libKSysGuardSystemStats2
This library is used by plugins for KSystemStats, a system monitoring daemon.

%package -n ksysguardsystemstats6-data
Summary:        Data needed by libKSysGuardSystemStats
Provides:       ksysguardsystemstats-data = %{version}
Obsoletes:      ksysguardsystemstats-data < %{version}

%description -n ksysguardsystemstats6-data
Contains the unversioned D-Bus interface definition for KSystemStats plugins.

%package plugins
Summary:        Task management and system monitoring library -- plugins
Requires:       libksysguard6 = %{version}
# For post and verifyscript
Requires(post): permissions
Requires(verify): permissions
Conflicts:      kdebase4-workspace < 5.3.0
Conflicts:      ksysguard5 < 5.21.80
Provides:       libksysguard5-plugins = %{version}
Obsoletes:      libksysguard5-plugins < %{version}
Provides:       libksysguard5-helper = %{version}
Obsoletes:      libksysguard5-helper < %{version}

%description plugins
Task management and system monitoring library. This package contains plugins.

%package imports
Summary:        Task management and system monitoring library -- QML bindings
Requires:       libksysguard6 = %{version}
Obsoletes:      libksysguard5-imports < %{version}

%description imports
This package provides QtQuick bindings for libksysguard, allowing its use in
QML applications.

%package devel
Summary:        Task management and system monitoring library -- devel files
Requires:       libKSysGuardSystemStats2 >= %{version}
Requires:       libksysguard6 >= %{version}
Requires:       cmake(KF6Config) >= %{kf6_version}
Requires:       cmake(KF6I18n) >= %{kf6_version}
Requires:       cmake(KF6IconThemes) >= %{kf6_version}
Requires:       cmake(Qt6Core) >= %{qt6_version}
Requires:       cmake(Qt6Network) >= %{qt6_version}
Requires:       cmake(Qt6Widgets) >= %{qt6_version}
Provides:       libksysguard5-devel = %{version}
Obsoletes:      libksysguard5-devel < %{version}

%description devel
Task management and system monitoring library. This package contains development
files.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%post plugins
%set_permissions %{_libexecdir}/ksysguard/ksgrd_network_helper

%verifyscript plugins
%verify_permissions -e %{_libexecdir}/ksysguard/ksgrd_network_helper

%ldconfig_scriptlets
%ldconfig_scriptlets -n libKSysGuardSystemStats2

%files
# TODO? split libraries and drop the -rpmlintrc file
%license LICENSES/*
%{_kf6_debugdir}/libksysguard.categories
%{_kf6_knsrcfilesdir}/systemmonitor-faces.knsrc
%{_kf6_knsrcfilesdir}/systemmonitor-presets.knsrc
%{_kf6_libdir}/libKSysGuardFormatter.so.*
%{_kf6_libdir}/libKSysGuardSensorFaces.so.*
%{_kf6_libdir}/libKSysGuardSensors.so.*
%{_kf6_libdir}/libprocesscore.so.*
%dir %{_kf6_plugindir}/kf6/packagestructure/
%{_kf6_plugindir}/kf6/packagestructure/ksysguard_sensorface.so
%{_kf6_sharedir}/ksysguard/

%files -n libKSysGuardSystemStats2
%license LICENSES/*
%{_kf6_libdir}/libKSysGuardSystemStats.so.*

%files -n ksysguardsystemstats6-data
%{_kf6_sharedir}/dbus-1/interfaces/org.kde.ksystemstats1.xml

%files plugins
%{_kf6_dbuspolicydir}/org.kde.ksysguard.processlisthelper.conf
%dir %{_kf6_plugindir}/ksysguard/
%dir %{_kf6_plugindir}/ksysguard/process
%{_kf6_plugindir}/ksysguard/process/ksysguard_plugin_network.so
%{_kf6_plugindir}/ksysguard/process/ksysguard_plugin_nvidia.so
%{_kf6_sharedir}/dbus-1/system-services/org.kde.ksysguard.processlisthelper.service
%{_kf6_sharedir}/polkit-1/actions/org.kde.ksysguard.processlisthelper.policy
%{_kf6_libexecdir}/kauth/ksysguardprocesslist_helper
%dir %{_libexecdir}/ksysguard/
%{_libexecdir}/ksysguard/ksgrd_network_helper

%files imports
%dir %{_kf6_qmldir}/org/kde/ksysguard
%{_kf6_qmldir}/org/kde/ksysguard/faces/
%{_kf6_qmldir}/org/kde/ksysguard/formatter/
%{_kf6_qmldir}/org/kde/ksysguard/process/
%{_kf6_qmldir}/org/kde/ksysguard/sensors/

%files devel
%{_includedir}/ksysguard/
%{_kf6_cmakedir}/KSysGuard/
%{_kf6_libdir}/libKSysGuardFormatter.so
%{_kf6_libdir}/libKSysGuardSensorFaces.so
%{_kf6_libdir}/libKSysGuardSensors.so
%{_kf6_libdir}/libKSysGuardSystemStats.so
%{_kf6_libdir}/libprocesscore.so

%files lang -f %{name}.lang

%changelog
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
  * Revert "processes_linux_p: ensure to have a single smaps read runnable"
  * faces/colorgrid: Replace grid implementation with the one from FaceGrid
  * faces: Ensure all compact reps always have at least some size (kde#492975)
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Too many changes to list here
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * faces/pie: Ensure text doesn't overflow the face (kde#453797)
  * update version for new release
  * processcore: Properly check if process exists before dereferencing (kde#445700)
  * faces/textonly: Change compact rep to be smaller and non interactive
  * faces/hbars: Tweak compact rep sizing to be more consitent and useful
  * faces/grid: Reduce margins in compact mode
  * faces/bar: Tweak compact sizing to ensure sensible consistent min size
  * faces: Port most compact representations to CompactSensorFace
  * faces/bars: Remove spacing on top and bottom of compact rep
  * faces/pie: Remove maximumHeight restriction from Pie chart in full rep (kde#486993)
  * faces: Introduce CompactSensorFace as base class for face compact rep
  * systemstats: Warn when overwriting a property in SensorObject
  * systemstats: Warn when trying to add an existing object to SensorContainer (kde#485025)
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Too many changes to list here
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
  * SensorFaceController: Create QQmlEngine for configs at class initialization
  * SensorFaceController: use a separate QQmlEngine in createConfigUi (kde#483689)
  * Fix linecharts and bar charts for small sizes (kde#483529)
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * update version for new release
  * colorgrid: Use the same background color as pie/bar charts (kde#482664)
  * faces/piechart: Explicitly set the thickness of the chart
  * faces/piechart: Don't hardcode background color but base it on theme
  * faces/horizontalbars: Repair compact representation (kde#481949)
  * faces/horizontalbars: Use a fixed background rather than relying on style (kde#480415)
* Fri Mar 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Drop meanwhile unnecessary BuildRequires on WebEngine and WebChannel
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
- Add Provides/Obsoletes for libksysguard5-helper (boo#1221350)
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
  * Handle the translations for systemstats
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * Drop all widgets related code
  * faces: Match BadgeOverlay's minimum font size for Pie Chart label minimum size
  * faces: Fix alignment of value in small Pie Chart face
  * faces: Do not try to assign undefined for updateInterval in LineChart
  * faces: Use a correct column span in FaceGrid if there are no sensors
  * faces: Fix implicit/minimum size of FaceGrid faces
  * faces: Fix FaceGrid config page
  * faces: Fix Choices delegate size and other porting bugs
  * faces/horizontalbars: Allow specifying the data range from config (kde#479573)
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- No code changes since 5.92.0
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Fri Jun  2 2023 Christophe Marin <christophe@krop.fr>
- Init libksysguard6
